Learn R Programming

courieR (version 0.2.2)

courieR-package: courieR: Migrate Installed R Packages Between R Versions

Description

Detects all R installations on the current machine and migrates installed R packages between them. Provides find_routes() to discover R versions, manifest() to scan package libraries via 'subprocess', inventory() to compare two libraries, and ship() to install packages into a target R version using 'pak'. Includes a Shiny dashboard (open_hub()) for interactive one-way and two-way migration.

Arguments

Author

Maintainer: Lennon Li yeli@biostats.ai

Authors:

See Also