Learn R Programming

courieR (version 0.2.2)

manifest: List packages installed in a library, optionally via a different R executable

Description

List packages installed in a library, optionally via a different R executable

Usage

manifest(
  rscript_path = NULL,
  lib_path = NULL,
  format = c("data.table", "data.frame"),
  timeout_sec = 30L
)

Value

data.table

Arguments

rscript_path

Path to the Rscript executable. Defaults to current session.

lib_path

Library path to query. Defaults to default .libPaths() of the target R.

format

Return format

timeout_sec

Timeout for subprocess

Examples

Run this code
# \donttest{
  pkgs <- manifest()
  head(pkgs)
# }

Run the code above in your browser using DataLab